# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .extraction_output_edits import ExtractionOutputEdits
from .file import File
from .json_object import JsonObject
from .processor_output import ProcessorOutput
from .processor_run_config import ProcessorRunConfig
from .processor_run_merged_processors_item import ProcessorRunMergedProcessorsItem
from .processor_run_status import ProcessorRunStatus
from .processor_run_type import ProcessorRunType


class ProcessorRun(UncheckedBaseModel):
    object: str = pydantic.Field()
    """
    The type of response. In this case, it will always be `"document_processor_run"`.
    """

    id: str = pydantic.Field()
    """
    The unique identifier for this processor run.
    
    Example: `"dpr_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")] = pydantic.Field()
    """
    The ID of the processor used for this run.
    
    Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_version_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorVersionId")] = pydantic.Field()
    """
    The ID of the specific processor version used.
    """

    processor_name: typing_extensions.Annotated[str, FieldMetadata(alias="processorName")] = pydantic.Field()
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    status: ProcessorRunStatus = pydantic.Field()
    """
    The current status of the processor run:
    * `"PROCESSING"` - The processor is currently running
    * `"PROCESSED"` - The processor has completed successfully
    * `"FAILED"` - The processor encountered an error
    * `"CANCELLED"` - The processor run was cancelled
    """

    output: ProcessorOutput = pydantic.Field()
    """
    The final output, either reviewed or initial.
    
    Conforms to the shape of output types and depends on the processor type and configuration shape.
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(default=None)
    )
    """
    If the run failed, indicates the reason for failure.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(default=None)
    )
    """
    If the run failed, provides a detailed message about the failure.
    """

    metadata: typing.Optional[JsonObject] = pydantic.Field(default=None)
    """
    Any metadata that was provided when creating the processor run.
    """

    reviewed: bool = pydantic.Field()
    """
    Indicates whether the run has been reviewed.
    """

    edited: bool = pydantic.Field()
    """
    Indicates whether the run results have been edited.
    """

    edits: typing.Dict[str, ExtractionOutputEdits]
    type: ProcessorRunType = pydantic.Field()
    """
    The type of processor:
    * `"CLASSIFY"` - Classifies documents into categories
    * `"EXTRACT"` - Extracts structured data from documents
    * `"SPLITTER"` - Splits documents into multiple parts
    """

    config: ProcessorRunConfig = pydantic.Field()
    """
    The configuration used for this processor run. The type of configuration will match the processor type.
    """

    initial_output: typing_extensions.Annotated[
        typing.Optional[ProcessorOutput], FieldMetadata(alias="initialOutput")
    ] = pydantic.Field(default=None)
    """
    The initial output from the processor run. The type of output will match the processor type.
    """

    reviewed_output: typing_extensions.Annotated[
        typing.Optional[ProcessorOutput], FieldMetadata(alias="reviewedOutput")
    ] = pydantic.Field(default=None)
    """
    The output after review, if any.
    """

    files: typing.List[File] = pydantic.Field()
    """
    Details of the processed files.
    
    If this was a file generated from a splitter processor, this will be the sub file.
    
    See the File object for more details.
    """

    merged_processors: typing_extensions.Annotated[
        typing.List[ProcessorRunMergedProcessorsItem], FieldMetadata(alias="mergedProcessors")
    ] = pydantic.Field()
    """
    An array of processors that were merged to create this output. Will be an empty array unless this output was the result of a MergeExtraction step in a workflow.
    """

    url: str = pydantic.Field()
    """
    The URL to view the processor run.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .extraction_field import ExtractionField  # noqa: E402, F401, I001

update_forward_refs(ProcessorRun)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    WorkflowRunCreateResponse,
    WorkflowRunDeleteResponse,
    WorkflowRunGetResponse,
    WorkflowRunListResponse,
    WorkflowRunUpdateResponse,
)

__all__ = [
    "WorkflowRunCreateResponse",
    "WorkflowRunDeleteResponse",
    "WorkflowRunGetResponse",
    "WorkflowRunListResponse",
    "WorkflowRunUpdateResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .chunk_metadata_page_range import ChunkMetadataPageRange


class ChunkMetadata(UncheckedBaseModel):
    """
    Metadata about the chunk.
    """

    page_range: typing_extensions.Annotated[ChunkMetadataPageRange, FieldMetadata(alias="pageRange")] = pydantic.Field()
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .batch_processor_run_get_response import BatchProcessorRunGetResponse

__all__ = ["BatchProcessorRunGetResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawParserRunClient, RawParserRunClient
from .types.parser_run_delete_response import ParserRunDeleteResponse
from .types.parser_run_get_request_response_type import ParserRunGetRequestResponseType
from .types.parser_run_get_response import ParserRunGetResponse


class ParserRunClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawParserRunClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawParserRunClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawParserRunClient
        """
        return self._raw_client

    def get(
        self,
        id: str,
        *,
        response_type: typing.Optional[ParserRunGetRequestResponseType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunGetResponse:
        """
        Retrieve the status and results of a parser run.

        Use this endpoint to get results for a parser run that has already completed, or to check on the status of an asynchronous parser run initiated via the [Parse File Asynchronously](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/parse-file-async) endpoint.

        If parsing is still in progress, you'll receive a response with just the status. Once complete, you'll receive the full parsed content in the response.

        Parameters
        ----------
        id : str
            The unique identifier for the parser run.

            Example: `"parser_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        response_type : typing.Optional[ParserRunGetRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns chunks with inline content
            * `url` - Returns chunks with presigned URLs to content instead of inline data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunGetResponse
            Successfully retrieved parser run

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.parser_run.get(id='parser_run_id_here', )
        """
        _response = self._raw_client.get(id, response_type=response_type, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ParserRunDeleteResponse:
        """
        Delete a parser run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the parser run to delete.

            Example: `"parser_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunDeleteResponse
            Successfully deleted parser run

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.parser_run.delete(id='parser_run_id_here', )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data


class AsyncParserRunClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawParserRunClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawParserRunClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawParserRunClient
        """
        return self._raw_client

    async def get(
        self,
        id: str,
        *,
        response_type: typing.Optional[ParserRunGetRequestResponseType] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunGetResponse:
        """
        Retrieve the status and results of a parser run.

        Use this endpoint to get results for a parser run that has already completed, or to check on the status of an asynchronous parser run initiated via the [Parse File Asynchronously](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/parse-file-async) endpoint.

        If parsing is still in progress, you'll receive a response with just the status. Once complete, you'll receive the full parsed content in the response.

        Parameters
        ----------
        id : str
            The unique identifier for the parser run.

            Example: `"parser_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        response_type : typing.Optional[ParserRunGetRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns chunks with inline content
            * `url` - Returns chunks with presigned URLs to content instead of inline data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunGetResponse
            Successfully retrieved parser run

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.parser_run.get(id='parser_run_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, response_type=response_type, request_options=request_options)
        return _response.data

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ParserRunDeleteResponse:
        """
        Delete a parser run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the parser run to delete.

            Example: `"parser_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunDeleteResponse
            Successfully deleted parser run

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.parser_run.delete(id='parser_run_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

ExtractionFieldType = typing.Union[
    typing.Literal["string", "number", "currency", "boolean", "date", "array", "enum", "object", "signature"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ApiVersionEnum,
    BadRequestErrorBody,
    BadRequestErrorBodyCode,
    BaseMetrics,
    BatchProcessorRun,
    BatchProcessorRunMetrics,
    BatchProcessorRunOptions,
    BatchProcessorRunSource,
    BatchProcessorRunStatus,
    BatchWorkflowRunFileInput,
    Block,
    BlockBoundingBox,
    BlockDetails,
    BlockMetadata,
    BlockMetadataPage,
    BlockPolygonItem,
    BlockType,
    Chunk,
    ChunkMetadata,
    ChunkMetadataPageRange,
    ChunkType,
    Citation,
    Classification,
    ClassificationAdvancedOptions,
    ClassificationAdvancedOptionsContext,
    ClassificationConfig,
    ClassificationConfigBaseProcessor,
    ClassifierOutput,
    ClassifyMetrics,
    EmptyBlockDetails,
    Enum,
    EnumOption,
    Error,
    EvaluationSet,
    EvaluationSetItem,
    ExtendError,
    ExtractChunkingOptions,
    ExtractChunkingOptionsChunkSelectionStrategy,
    ExtractChunkingOptionsChunkingStrategy,
    ExtractMetrics,
    ExtractMetricsFieldMetrics,
    ExtractionAdvancedOptions,
    ExtractionConfig,
    ExtractionConfigBaseProcessor,
    ExtractionField,
    ExtractionFieldResult,
    ExtractionFieldResultReference,
    ExtractionFieldResultReferenceBoundingBoxesItem,
    ExtractionFieldResultType,
    ExtractionFieldType,
    ExtractionOutput,
    ExtractionOutputEdits,
    FieldsArrayOutput,
    FigureDetails,
    FigureDetailsFigureType,
    File,
    FileContents,
    FileContentsPagesItem,
    FileContentsSheetsItem,
    FileMetadata,
    FileMetadataParentSplit,
    FileType,
    Insight,
    JsonObject,
    JsonOutput,
    JsonOutputMetadataValue,
    JsonOutputMetadataValueCitationsItem,
    JsonOutputMetadataValueCitationsItemPolygonItem,
    JsonOutputMetadataValueInsightsItem,
    MaxPageSize,
    NextPageToken,
    OutputMetadata,
    OutputMetadataValue,
    PageRanges,
    PageRangesItem,
    ParseAsyncRequestFile,
    ParseConfig,
    ParseConfigAdvancedOptions,
    ParseConfigBlockOptions,
    ParseConfigBlockOptionsFigures,
    ParseConfigBlockOptionsTables,
    ParseConfigBlockOptionsTablesTargetFormat,
    ParseConfigBlockOptionsText,
    ParseConfigChunkingStrategy,
    ParseConfigChunkingStrategyOptions,
    ParseConfigChunkingStrategyType,
    ParseConfigTarget,
    ParseError,
    ParseErrorCode,
    ParseRequestFile,
    ParseRequestResponseType,
    ParserRun,
    ParserRunMetrics,
    ParserRunStatus,
    ParserRunStatusEnum,
    ParserRunStatusStatus,
    Polygon,
    Processor,
    ProcessorId,
    ProcessorOutput,
    ProcessorRun,
    ProcessorRunConfig,
    ProcessorRunConfig_Classify,
    ProcessorRunConfig_Extract,
    ProcessorRunConfig_Splitter,
    ProcessorRunFileInput,
    ProcessorRunMergedProcessorsItem,
    ProcessorRunStatus,
    ProcessorRunType,
    ProcessorType,
    ProcessorVersion,
    ProcessorVersionConfig,
    ProcessorVersionConfig_Classify,
    ProcessorVersionConfig_Extract,
    ProcessorVersionConfig_Splitter,
    ProvidedClassifierOutput,
    ProvidedExtractionFieldResult,
    ProvidedExtractionFieldResultType,
    ProvidedExtractionOutput,
    ProvidedFieldsArrayOutput,
    ProvidedJsonOutput,
    ProvidedProcessorOutput,
    ProvidedSplitterOutput,
    ProvidedSplitterOutputSplitsItem,
    SortByEnum,
    SortDirEnum,
    SplitterAdvancedOptions,
    SplitterAdvancedOptionsSplitMethod,
    SplitterConfig,
    SplitterConfigBaseProcessor,
    SplitterMetrics,
    SplitterOutput,
    SplitterOutputSplitsItem,
    StepRun,
    StepRunOutput,
    StepRunOutputRulesItem,
    StepRunOutputRulesItemFailureReason,
    StepRunStatus,
    StepRunStep,
    StepRunStepType,
    TableCellDetails,
    TableDetails,
    TooManyRequestsErrorBody,
    WebhookEvent,
    WebhookEventEventType,
    WebhookEventPayload,
    WebhookEventProcessor,
    WebhookEventProcessorEventType,
    WebhookEventProcessorRun,
    WebhookEventProcessorRunEventType,
    WebhookEventProcessorVersion,
    WebhookEventWorkflow,
    WebhookEventWorkflowEventType,
    WebhookEventWorkflowRun,
    WebhookEventWorkflowRunEventType,
    Workflow,
    WorkflowRun,
    WorkflowRunFileInput,
    WorkflowRunFileInputOutputsItem,
    WorkflowRunSummary,
    WorkflowStatus,
)
from .errors import (
    BadRequestError,
    InternalServerError,
    NotFoundError,
    PaymentRequiredError,
    TooManyRequestsError,
    UnauthorizedError,
    UnprocessableEntityError,
)
from . import (
    batch_processor_run,
    batch_workflow_run,
    evaluation_set,
    evaluation_set_item,
    file,
    parser_run,
    processor,
    processor_run,
    processor_version,
    workflow,
    workflow_run,
    workflow_run_output,
)
from .batch_processor_run import BatchProcessorRunGetResponse
from .batch_workflow_run import BatchWorkflowRunCreateRequestInputsItem, BatchWorkflowRunCreateResponse
from .client import AsyncExtend, Extend
from .environment import ExtendEnvironment
from .evaluation_set import EvaluationSetCreateResponse, EvaluationSetGetResponse, EvaluationSetListResponse
from .evaluation_set_item import (
    EvaluationSetItemCreateBatchRequestItemsItem,
    EvaluationSetItemCreateBatchResponse,
    EvaluationSetItemCreateResponse,
    EvaluationSetItemListResponse,
    EvaluationSetItemUpdateResponse,
)
from .file import FileDeleteResponse, FileGetResponse, FileListResponse, FileUploadResponse
from .parser_run import (
    ParserRunDeleteResponse,
    ParserRunGetRequestResponseType,
    ParserRunGetResponse,
    ParserRunGetResponseParserRun,
    ParserRunGetResponseParserRun_ParserRun,
    ParserRunGetResponseParserRun_ParserRunStatus,
)
from .processor import (
    ProcessorCreateRequestConfig,
    ProcessorCreateRequestConfig_Classify,
    ProcessorCreateRequestConfig_Extract,
    ProcessorCreateRequestConfig_Splitter,
    ProcessorCreateResponse,
    ProcessorUpdateRequestConfig,
    ProcessorUpdateRequestConfig_Classify,
    ProcessorUpdateRequestConfig_Extract,
    ProcessorUpdateRequestConfig_Splitter,
    ProcessorUpdateResponse,
)
from .processor_run import (
    ProcessorRunCancelResponse,
    ProcessorRunCreateRequestConfig,
    ProcessorRunCreateRequestConfig_Classify,
    ProcessorRunCreateRequestConfig_Extract,
    ProcessorRunCreateRequestConfig_Splitter,
    ProcessorRunCreateResponse,
    ProcessorRunDeleteResponse,
    ProcessorRunGetResponse,
)
from .processor_version import (
    ProcessorVersionCreateRequestConfig,
    ProcessorVersionCreateRequestConfig_Classify,
    ProcessorVersionCreateRequestConfig_Extract,
    ProcessorVersionCreateRequestConfig_Splitter,
    ProcessorVersionCreateRequestReleaseType,
    ProcessorVersionCreateResponse,
    ProcessorVersionGetResponse,
    ProcessorVersionListResponse,
)
from .version import __version__
from .workflow import WorkflowCreateResponse
from .workflow_run import (
    WorkflowRunCreateResponse,
    WorkflowRunDeleteResponse,
    WorkflowRunGetResponse,
    WorkflowRunListResponse,
    WorkflowRunUpdateResponse,
)
from .workflow_run_output import WorkflowRunOutputUpdateResponse

__all__ = [
    "ApiVersionEnum",
    "AsyncExtend",
    "BadRequestError",
    "BadRequestErrorBody",
    "BadRequestErrorBodyCode",
    "BaseMetrics",
    "BatchProcessorRun",
    "BatchProcessorRunGetResponse",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchWorkflowRunCreateRequestInputsItem",
    "BatchWorkflowRunCreateResponse",
    "BatchWorkflowRunFileInput",
    "Block",
    "BlockBoundingBox",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "Classification",
    "ClassificationAdvancedOptions",
    "ClassificationAdvancedOptionsContext",
    "ClassificationConfig",
    "ClassificationConfigBaseProcessor",
    "ClassifierOutput",
    "ClassifyMetrics",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "Error",
    "EvaluationSet",
    "EvaluationSetCreateResponse",
    "EvaluationSetGetResponse",
    "EvaluationSetItem",
    "EvaluationSetItemCreateBatchRequestItemsItem",
    "EvaluationSetItemCreateBatchResponse",
    "EvaluationSetItemCreateResponse",
    "EvaluationSetItemListResponse",
    "EvaluationSetItemUpdateResponse",
    "EvaluationSetListResponse",
    "Extend",
    "ExtendEnvironment",
    "ExtendError",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractMetrics",
    "ExtractMetricsFieldMetrics",
    "ExtractionAdvancedOptions",
    "ExtractionConfig",
    "ExtractionConfigBaseProcessor",
    "ExtractionField",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "ExtractionOutput",
    "ExtractionOutputEdits",
    "FieldsArrayOutput",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSheetsItem",
    "FileDeleteResponse",
    "FileGetResponse",
    "FileListResponse",
    "FileMetadata",
    "FileMetadataParentSplit",
    "FileType",
    "FileUploadResponse",
    "Insight",
    "InternalServerError",
    "JsonObject",
    "JsonOutput",
    "JsonOutputMetadataValue",
    "JsonOutputMetadataValueCitationsItem",
    "JsonOutputMetadataValueCitationsItemPolygonItem",
    "JsonOutputMetadataValueInsightsItem",
    "MaxPageSize",
    "NextPageToken",
    "NotFoundError",
    "OutputMetadata",
    "OutputMetadataValue",
    "PageRanges",
    "PageRangesItem",
    "ParseAsyncRequestFile",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigTarget",
    "ParseError",
    "ParseErrorCode",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParserRun",
    "ParserRunDeleteResponse",
    "ParserRunGetRequestResponseType",
    "ParserRunGetResponse",
    "ParserRunGetResponseParserRun",
    "ParserRunGetResponseParserRun_ParserRun",
    "ParserRunGetResponseParserRun_ParserRunStatus",
    "ParserRunMetrics",
    "ParserRunStatus",
    "ParserRunStatusEnum",
    "ParserRunStatusStatus",
    "PaymentRequiredError",
    "Polygon",
    "Processor",
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorId",
    "ProcessorOutput",
    "ProcessorRun",
    "ProcessorRunCancelResponse",
    "ProcessorRunConfig",
    "ProcessorRunConfig_Classify",
    "ProcessorRunConfig_Extract",
    "ProcessorRunConfig_Splitter",
    "ProcessorRunCreateRequestConfig",
    "ProcessorRunCreateRequestConfig_Classify",
    "ProcessorRunCreateRequestConfig_Extract",
    "ProcessorRunCreateRequestConfig_Splitter",
    "ProcessorRunCreateResponse",
    "ProcessorRunDeleteResponse",
    "ProcessorRunFileInput",
    "ProcessorRunGetResponse",
    "ProcessorRunMergedProcessorsItem",
    "ProcessorRunStatus",
    "ProcessorRunType",
    "ProcessorType",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
    "ProcessorVersion",
    "ProcessorVersionConfig",
    "ProcessorVersionConfig_Classify",
    "ProcessorVersionConfig_Extract",
    "ProcessorVersionConfig_Splitter",
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
    "ProvidedClassifierOutput",
    "ProvidedExtractionFieldResult",
    "ProvidedExtractionFieldResultType",
    "ProvidedExtractionOutput",
    "ProvidedFieldsArrayOutput",
    "ProvidedJsonOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitterOutput",
    "ProvidedSplitterOutputSplitsItem",
    "SortByEnum",
    "SortDirEnum",
    "SplitterAdvancedOptions",
    "SplitterAdvancedOptionsSplitMethod",
    "SplitterConfig",
    "SplitterConfigBaseProcessor",
    "SplitterMetrics",
    "SplitterOutput",
    "SplitterOutputSplitsItem",
    "StepRun",
    "StepRunOutput",
    "StepRunOutputRulesItem",
    "StepRunOutputRulesItemFailureReason",
    "StepRunStatus",
    "StepRunStep",
    "StepRunStepType",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsError",
    "TooManyRequestsErrorBody",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "WebhookEvent",
    "WebhookEventEventType",
    "WebhookEventPayload",
    "WebhookEventProcessor",
    "WebhookEventProcessorEventType",
    "WebhookEventProcessorRun",
    "WebhookEventProcessorRunEventType",
    "WebhookEventProcessorVersion",
    "WebhookEventWorkflow",
    "WebhookEventWorkflowEventType",
    "WebhookEventWorkflowRun",
    "WebhookEventWorkflowRunEventType",
    "Workflow",
    "WorkflowCreateResponse",
    "WorkflowRun",
    "WorkflowRunCreateResponse",
    "WorkflowRunDeleteResponse",
    "WorkflowRunFileInput",
    "WorkflowRunFileInputOutputsItem",
    "WorkflowRunGetResponse",
    "WorkflowRunListResponse",
    "WorkflowRunOutputUpdateResponse",
    "WorkflowRunSummary",
    "WorkflowRunUpdateResponse",
    "WorkflowStatus",
    "__version__",
    "batch_processor_run",
    "batch_workflow_run",
    "evaluation_set",
    "evaluation_set_item",
    "file",
    "parser_run",
    "processor",
    "processor_run",
    "processor_version",
    "workflow",
    "workflow_run",
    "workflow_run_output",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .file_contents_pages_item import FileContentsPagesItem
from .file_contents_sheets_item import FileContentsSheetsItem


class FileContents(UncheckedBaseModel):
    raw_text: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rawText")] = pydantic.Field(
        default=None
    )
    """
    The raw text content of the file. This is included for all file types if the `rawText` query parameter is set to true in the endpoint request.
    """

    markdown: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cleaned and structured markdown content of the entire file. Available for PDF and IMG file types. Only included if the `markdown` query parameter is set to true in the endpoint request.
    """

    pages: typing.Optional[typing.List[FileContentsPagesItem]] = None
    sheets: typing.Optional[typing.List[FileContentsSheetsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .classification import Classification
from .classification_advanced_options import ClassificationAdvancedOptions
from .classification_config_base_processor import ClassificationConfigBaseProcessor
from .extraction_advanced_options import ExtractionAdvancedOptions
from .extraction_config_base_processor import ExtractionConfigBaseProcessor
from .json_object import JsonObject
from .parse_config import ParseConfig
from .splitter_advanced_options import SplitterAdvancedOptions
from .splitter_config_base_processor import SplitterConfigBaseProcessor


class ProcessorVersionConfig_Classify(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["CLASSIFY"] = "CLASSIFY"
    base_processor: typing_extensions.Annotated[
        typing.Optional[ClassificationConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    classifications: typing.List[Classification]
    classification_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="classificationRules")
    ] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[ClassificationAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorVersionConfig_Extract(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["EXTRACT"] = "EXTRACT"
    base_processor: typing_extensions.Annotated[
        typing.Optional[ExtractionConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    extraction_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="extractionRules")] = None
    schema_: typing_extensions.Annotated[typing.Optional[JsonObject], FieldMetadata(alias="schema")] = None
    fields: typing.Optional[typing.List["ExtractionField"]] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[ExtractionAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .extraction_field import ExtractionField  # noqa: E402, F401, I001


class ProcessorVersionConfig_Splitter(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["SPLITTER"] = "SPLITTER"
    base_processor: typing_extensions.Annotated[
        typing.Optional[SplitterConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    split_classifications: typing_extensions.Annotated[
        typing.List[Classification], FieldMetadata(alias="splitClassifications")
    ]
    split_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="splitRules")] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[SplitterAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ProcessorVersionConfig = typing_extensions.Annotated[
    typing.Union[ProcessorVersionConfig_Classify, ProcessorVersionConfig_Extract, ProcessorVersionConfig_Splitter],
    UnionMetadata(discriminant="type"),
]
update_forward_refs(ProcessorVersionConfig_Extract)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.evaluation_set_item import EvaluationSetItem


class EvaluationSetItemUpdateResponse(UncheckedBaseModel):
    success: bool
    evaluation_set_item: typing_extensions.Annotated[EvaluationSetItem, FieldMetadata(alias="evaluationSetItem")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventProcessorEventType = typing.Union[
    typing.Literal["processor.created", "processor.updated", "processor.deleted", "processor.draft.updated"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .classifier_output import ClassifierOutput
from .extraction_output import ExtractionOutput
from .splitter_output import SplitterOutput

ProcessorOutput = typing.Union[ExtractionOutput, ClassifierOutput, SplitterOutput]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .enum import Enum
from .extraction_field_type import ExtractionFieldType


class ExtractionField(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    Unique identifier for the field.
    """

    name: str = pydantic.Field()
    """
    Human-readable name for the field.
    """

    type: ExtractionFieldType = pydantic.Field()
    """
    The type of the field.
    """

    description: str = pydantic.Field()
    """
    Detailed description of the field, including expected content and format.
    """

    schema_: typing_extensions.Annotated[
        typing.Optional[typing.List["ExtractionField"]], FieldMetadata(alias="schema")
    ] = pydantic.Field(default=None)
    """
    Required when type is "array" or "object". Contains nested field definitions.
    """

    enum: typing.Optional[typing.List[Enum]] = pydantic.Field(default=None)
    """
    Required when type is "enum". List of allowed values.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ExtractionField)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .file_delete_response import FileDeleteResponse
from .file_get_response import FileGetResponse
from .file_list_response import FileListResponse
from .file_upload_response import FileUploadResponse

__all__ = ["FileDeleteResponse", "FileGetResponse", "FileListResponse", "FileUploadResponse"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .workflow_run_output_update_response import WorkflowRunOutputUpdateResponse

__all__ = ["WorkflowRunOutputUpdateResponse"]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.workflow_run import WorkflowRun


class WorkflowRunCreateResponse(UncheckedBaseModel):
    success: bool
    workflow_runs: typing_extensions.Annotated[typing.List[WorkflowRun], FieldMetadata(alias="workflowRuns")] = (
        pydantic.Field()
    )
    """
    An array of WorkflowRun objects, with each WorkflowRun corresponding to a single File that was passed in.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from ...types.extraction_field import ExtractionField  # noqa: E402, F401, I001

update_forward_refs(WorkflowRunCreateResponse)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .batch_workflow_run_create_request_inputs_item import BatchWorkflowRunCreateRequestInputsItem
from .batch_workflow_run_create_response import BatchWorkflowRunCreateResponse

__all__ = ["BatchWorkflowRunCreateRequestInputsItem", "BatchWorkflowRunCreateResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from .base_metrics import BaseMetrics


class ClassifyMetrics(BaseMetrics):
    """
    Metrics specific to classification processors
    """

    type: typing.Optional[typing.Literal["CLASSIFY"]] = pydantic.Field(default=None)
    """
    The type of metrics. Will always be `"CLASSIFY"` for classification processors.
    """

    accuracy_perc: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="accuracyPerc")] = (
        pydantic.Field(default=None)
    )
    """
    The overall accuracy percentage.
    """

    mean_confidence: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="meanConfidence")] = (
        pydantic.Field(default=None)
    )
    """
    The mean confidence score.
    """

    distribution: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Record mapping classification values to their counts.
    """

    accuracy_perc_by_classification: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]],
        FieldMetadata(alias="accuracyPercByClassification"),
    ] = pydantic.Field(default=None)
    """
    Mapping from classification to accuracy percentage as calculated from the confusion matrix.
    """

    confusion_matrix: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="confusionMatrix")
    ] = pydantic.Field(default=None)
    """
    Mapping from actual class to predicted class to count. Only present when accuracy percentage is present.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .batch_processor_run.client import AsyncBatchProcessorRunClient, BatchProcessorRunClient
from .batch_workflow_run.client import AsyncBatchWorkflowRunClient, BatchWorkflowRunClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .environment import ExtendEnvironment
from .evaluation_set.client import AsyncEvaluationSetClient, EvaluationSetClient
from .evaluation_set_item.client import AsyncEvaluationSetItemClient, EvaluationSetItemClient
from .file.client import AsyncFileClient, FileClient
from .parser_run.client import AsyncParserRunClient, ParserRunClient
from .processor.client import AsyncProcessorClient, ProcessorClient
from .processor_run.client import AsyncProcessorRunClient, ProcessorRunClient
from .processor_version.client import AsyncProcessorVersionClient, ProcessorVersionClient
from .raw_client import AsyncRawExtend, RawExtend
from .types.parse_async_request_file import ParseAsyncRequestFile
from .types.parse_config import ParseConfig
from .types.parse_request_file import ParseRequestFile
from .types.parse_request_response_type import ParseRequestResponseType
from .types.parser_run import ParserRun
from .types.parser_run_status import ParserRunStatus
from .workflow.client import AsyncWorkflowClient, WorkflowClient
from .workflow_run.client import AsyncWorkflowRunClient, WorkflowRunClient
from .workflow_run_output.client import AsyncWorkflowRunOutputClient, WorkflowRunOutputClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class Extend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment

        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import Extend
    client = Extend(token="YOUR_TOKEN", )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = RawExtend(client_wrapper=self._client_wrapper)
        self.workflow_run = WorkflowRunClient(client_wrapper=self._client_wrapper)
        self.batch_workflow_run = BatchWorkflowRunClient(client_wrapper=self._client_wrapper)
        self.processor_run = ProcessorRunClient(client_wrapper=self._client_wrapper)
        self.processor = ProcessorClient(client_wrapper=self._client_wrapper)
        self.processor_version = ProcessorVersionClient(client_wrapper=self._client_wrapper)
        self.parser_run = ParserRunClient(client_wrapper=self._client_wrapper)
        self.file = FileClient(client_wrapper=self._client_wrapper)
        self.evaluation_set = EvaluationSetClient(client_wrapper=self._client_wrapper)
        self.evaluation_set_item = EvaluationSetItemClient(client_wrapper=self._client_wrapper)
        self.workflow_run_output = WorkflowRunOutputClient(client_wrapper=self._client_wrapper)
        self.batch_processor_run = BatchProcessorRunClient(client_wrapper=self._client_wrapper)
        self.workflow = WorkflowClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> RawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExtend
        """
        return self._raw_client

    def parse(
        self,
        *,
        file: ParseRequestFile,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRun:
        """
        Parse files to get cleaned, chunked target content (e.g. markdown).

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFile
            A file object containing either a URL or a fileId.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRun
            Successfully parsed file

        Examples
        --------
        from extend_ai import Extend
        from extend_ai import ParseRequestFile
        client = Extend(token="YOUR_TOKEN", )
        client.parse(file=ParseRequestFile(), )
        """
        _response = self._raw_client.parse(
            file=file, response_type=response_type, config=config, request_options=request_options
        )
        return _response.data

    def parse_async(
        self,
        *,
        file: ParseAsyncRequestFile,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunStatus:
        """
        Parse files **asynchronously** to get cleaned, chunked target content (e.g. markdown).

        The Parse Async endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        Parse files asynchronously and get a parser run ID that can be used to check status and retrieve results with the [Get Parser Run](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/get-parser-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous parsing.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunStatus
            Successfully initiated parser run

        Examples
        --------
        from extend_ai import Extend
        from extend_ai import ParseAsyncRequestFile
        client = Extend(token="YOUR_TOKEN", )
        client.parse_async(file=ParseAsyncRequestFile(), )
        """
        _response = self._raw_client.parse_async(file=file, config=config, request_options=request_options)
        return _response.data


class AsyncExtend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment

        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import AsyncExtend
    client = AsyncExtend(token="YOUR_TOKEN", )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = AsyncRawExtend(client_wrapper=self._client_wrapper)
        self.workflow_run = AsyncWorkflowRunClient(client_wrapper=self._client_wrapper)
        self.batch_workflow_run = AsyncBatchWorkflowRunClient(client_wrapper=self._client_wrapper)
        self.processor_run = AsyncProcessorRunClient(client_wrapper=self._client_wrapper)
        self.processor = AsyncProcessorClient(client_wrapper=self._client_wrapper)
        self.processor_version = AsyncProcessorVersionClient(client_wrapper=self._client_wrapper)
        self.parser_run = AsyncParserRunClient(client_wrapper=self._client_wrapper)
        self.file = AsyncFileClient(client_wrapper=self._client_wrapper)
        self.evaluation_set = AsyncEvaluationSetClient(client_wrapper=self._client_wrapper)
        self.evaluation_set_item = AsyncEvaluationSetItemClient(client_wrapper=self._client_wrapper)
        self.workflow_run_output = AsyncWorkflowRunOutputClient(client_wrapper=self._client_wrapper)
        self.batch_processor_run = AsyncBatchProcessorRunClient(client_wrapper=self._client_wrapper)
        self.workflow = AsyncWorkflowClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExtend
        """
        return self._raw_client

    async def parse(
        self,
        *,
        file: ParseRequestFile,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRun:
        """
        Parse files to get cleaned, chunked target content (e.g. markdown).

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFile
            A file object containing either a URL or a fileId.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRun
            Successfully parsed file

        Examples
        --------
        from extend_ai import AsyncExtend
        from extend_ai import ParseRequestFile
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.parse(file=ParseRequestFile(), )
        asyncio.run(main())
        """
        _response = await self._raw_client.parse(
            file=file, response_type=response_type, config=config, request_options=request_options
        )
        return _response.data

    async def parse_async(
        self,
        *,
        file: ParseAsyncRequestFile,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunStatus:
        """
        Parse files **asynchronously** to get cleaned, chunked target content (e.g. markdown).

        The Parse Async endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        Parse files asynchronously and get a parser run ID that can be used to check status and retrieve results with the [Get Parser Run](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/get-parser-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous parsing.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunStatus
            Successfully initiated parser run

        Examples
        --------
        from extend_ai import AsyncExtend
        from extend_ai import ParseAsyncRequestFile
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.parse_async(file=ParseAsyncRequestFile(), )
        asyncio.run(main())
        """
        _response = await self._raw_client.parse_async(file=file, config=config, request_options=request_options)
        return _response.data


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ExtendEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class FileContentsPagesItem(UncheckedBaseModel):
    page_number: typing_extensions.Annotated[int, FieldMetadata(alias="pageNumber")] = pydantic.Field()
    """
    The page number of this page in the document.
    """

    page_height: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="pageHeight")] = None
    page_width: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="pageWidth")] = None
    raw_text: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rawText")] = pydantic.Field(
        default=None
    )
    """
    The raw text content extracted from this page.
    """

    markdown: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cleaned and structured markdown content of this page.
    """

    html: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cleaned and structured html content of the page. Available for DOCX file types (that were not auto-converted to PDFs). Only included if the `html` query parameter is set to true in the endpoint request.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_dir_enum import SortDirEnum
from .raw_client import AsyncRawFileClient, RawFileClient
from .types.file_delete_response import FileDeleteResponse
from .types.file_get_response import FileGetResponse
from .types.file_list_response import FileListResponse
from .types.file_upload_response import FileUploadResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FileClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFileClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFileClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFileClient
        """
        return self._raw_client

    def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileListResponse:
        """
        List files in your account. Files represent documents that have been uploaded to Extend. This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the files in ascending or descending order. Ascending order means the earliest file is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileListResponse
            Successfully retrieved files

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.file.list(next_page_token='xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=', )
        """
        _response = self._raw_client.list(
            name_contains=name_contains,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def get(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileGetResponse:
        """
        Fetch a file by its ID to obtain additional details and the raw file content.

        Parameters
        ----------
        id : str
            Extend's ID for the file. It will always start with `"file_"`. This ID is returned when creating a new File, or the value on the `fileId` field in a WorkflowRun.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            If set to true, the raw text content of the file will be included in the response. This is useful for indexing text-based files like PDFs, Word Documents, etc.

        markdown : typing.Optional[bool]
            If set to true, the markdown content of the file will be included in the response. This is useful for indexing very clean content into RAG pipelines for files like PDFs, Word Documents, etc.

            Only available for files with a type of PDF, IMG, or .doc/.docx files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            If set to true, the html content of the file will be included in the response. This is useful for indexing html content into RAG pipelines.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileGetResponse
            Successfully retrieved file

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.file.get(id='file_id_here', )
        """
        _response = self._raw_client.get(
            id, raw_text=raw_text, markdown=markdown, html=html, request_options=request_options
        )
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> FileDeleteResponse:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileDeleteResponse
            Successfully deleted file

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.file.delete(id='file_id_here', )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def upload(self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None) -> FileUploadResponse:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2025-04-21/developers/api-reference/workflow-endpoints/run-workflow), [creating evaluation set items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](/product/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileUploadResponse
            Successfully uploaded file

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.file.upload()
        """
        _response = self._raw_client.upload(file=file, request_options=request_options)
        return _response.data


class AsyncFileClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFileClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFileClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFileClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileListResponse:
        """
        List files in your account. Files represent documents that have been uploaded to Extend. This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the files in ascending or descending order. Ascending order means the earliest file is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileListResponse
            Successfully retrieved files

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.file.list(next_page_token='xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=', )
        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            name_contains=name_contains,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileGetResponse:
        """
        Fetch a file by its ID to obtain additional details and the raw file content.

        Parameters
        ----------
        id : str
            Extend's ID for the file. It will always start with `"file_"`. This ID is returned when creating a new File, or the value on the `fileId` field in a WorkflowRun.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            If set to true, the raw text content of the file will be included in the response. This is useful for indexing text-based files like PDFs, Word Documents, etc.

        markdown : typing.Optional[bool]
            If set to true, the markdown content of the file will be included in the response. This is useful for indexing very clean content into RAG pipelines for files like PDFs, Word Documents, etc.

            Only available for files with a type of PDF, IMG, or .doc/.docx files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            If set to true, the html content of the file will be included in the response. This is useful for indexing html content into RAG pipelines.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileGetResponse
            Successfully retrieved file

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.file.get(id='file_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            id, raw_text=raw_text, markdown=markdown, html=html, request_options=request_options
        )
        return _response.data

    async def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> FileDeleteResponse:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileDeleteResponse
            Successfully deleted file

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.file.delete(id='file_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def upload(
        self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None
    ) -> FileUploadResponse:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2025-04-21/developers/api-reference/workflow-endpoints/run-workflow), [creating evaluation set items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](/product/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileUploadResponse
            Successfully uploaded file

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.file.upload()
        asyncio.run(main())
        """
        _response = await self._raw_client.upload(file=file, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class BaseMetrics(UncheckedBaseModel):
    """
    Base metrics common to all processor types
    """

    num_files: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="numFiles")] = pydantic.Field(
        default=None
    )
    """
    The total number of files that were processed.
    """

    num_pages: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="numPages")] = pydantic.Field(
        default=None
    )
    """
    The total number of pages that were processed.
    """

    mean_run_time_ms: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="meanRunTimeMs")] = (
        pydantic.Field(default=None)
    )
    """
    The mean runtime in milliseconds per document.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ProcessorCreateRequestConfig,
    ProcessorCreateRequestConfig_Classify,
    ProcessorCreateRequestConfig_Extract,
    ProcessorCreateRequestConfig_Splitter,
    ProcessorCreateResponse,
    ProcessorUpdateRequestConfig,
    ProcessorUpdateRequestConfig_Classify,
    ProcessorUpdateRequestConfig_Extract,
    ProcessorUpdateRequestConfig_Splitter,
    ProcessorUpdateResponse,
)

__all__ = [
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .block import Block
from .chunk_metadata import ChunkMetadata
from .chunk_type import ChunkType


class Chunk(UncheckedBaseModel):
    object: str = pydantic.Field()
    """
    The type of object. In this case, it will always be `"chunk"`.
    """

    type: ChunkType = pydantic.Field()
    """
    The type of chunk.
    """

    content: str = pydantic.Field()
    """
    The parsed content of the chunk.
    """

    metadata: ChunkMetadata = pydantic.Field()
    """
    Metadata about the chunk.
    """

    blocks: typing.List[Block] = pydantic.Field()
    """
    An array of block objects that make up the chunk. A Block represents a distinct content element within a document, such as a paragraph of text, a heading, a table, or a figure. Blocks are the fundamental units that make up chunks in parsed documents.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_classifier_output import ProvidedClassifierOutput
from .provided_extraction_output import ProvidedExtractionOutput
from .provided_splitter_output import ProvidedSplitterOutput

ProvidedProcessorOutput = typing.Union[ProvidedExtractionOutput, ProvidedClassifierOutput, ProvidedSplitterOutput]



# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventWorkflowRunEventType = typing.Union[
    typing.Literal[
        "workflow_run.completed",
        "workflow_run.failed",
        "workflow_run.needs_review",
        "workflow_run.rejected",
        "workflow_run.step_run.processed",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_by_enum import SortByEnum
from ..types.sort_dir_enum import SortDirEnum
from .raw_client import AsyncRawEvaluationSetClient, RawEvaluationSetClient
from .types.evaluation_set_create_response import EvaluationSetCreateResponse
from .types.evaluation_set_get_response import EvaluationSetGetResponse
from .types.evaluation_set_list_response import EvaluationSetListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EvaluationSetClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEvaluationSetClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEvaluationSetClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEvaluationSetClient
        """
        return self._raw_client

    def list(
        self,
        *,
        processor_id: typing.Optional[str] = None,
        sort_by: typing.Optional[SortByEnum] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvaluationSetListResponse:
        """
        List evaluation sets in your account. You can use the `processorId` parameter to filter evaluation sets by processor.

        This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        processor_id : typing.Optional[str]
            The ID of the processor to filter evaluation sets by.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_by : typing.Optional[SortByEnum]
            Sorts the evaluation sets by the given field.

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the evaluation sets in ascending or descending order. Ascending order means the earliest evaluation set is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetListResponse
            Successfully retrieved evaluation sets

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.evaluation_set.list(processor_id='processor_id_here', next_page_token='xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=', )
        """
        _response = self._raw_client.list(
            processor_id=processor_id,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def create(
        self, *, name: str, description: str, processor_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> EvaluationSetCreateResponse:
        """
        Evaluation sets are collections of files and expected outputs that are used to evaluate the performance of a given processor in Extend. This endpoint will create a new evaluation set in Extend, which items can be added to using the [Create Evaluation Set Item](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/create-evaluation-set-item) endpoint.

        Note: it is not necessary to create an evaluation set via API. You can also create an evaluation set via the Extend dashboard and take the ID from there.

        Parameters
        ----------
        name : str
            The name of the evaluation set.

            Example: `"Invoice Processing Test Set"`

        description : str
            A description of what this evaluation set is used for.

            Example: `"Q4 2023 vendor invoices"`

        processor_id : str
            The ID of the processor to create an evaluation set for. Evaluation sets can in theory be run against any processor, but it is required to associate the evaluation set with a primary processor.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetCreateResponse
            Successfully created evaluation set

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.evaluation_set.create(name='My Evaluation Set', description='My Evaluation Set Description', processor_id='processor_id_here', )
        """
        _response = self._raw_client.create(
            name=name, description=description, processor_id=processor_id, request_options=request_options
        )
        return _response.data

    def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EvaluationSetGetResponse:
        """
        Retrieve a specific evaluation set by ID. This returns an evaluation set object, but does not include the items in the evaluation set. You can use the [List Evaluation Set Items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/list-evaluation-set-items) endpoint to get the items in an evaluation set.

        Parameters
        ----------
        id : str
            The ID of the evaluation set to retrieve.

            Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetGetResponse
            Successfully retrieved evaluation set

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.evaluation_set.get(id='evaluation_set_id_here', )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data


class AsyncEvaluationSetClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEvaluationSetClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEvaluationSetClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEvaluationSetClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        processor_id: typing.Optional[str] = None,
        sort_by: typing.Optional[SortByEnum] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EvaluationSetListResponse:
        """
        List evaluation sets in your account. You can use the `processorId` parameter to filter evaluation sets by processor.

        This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        processor_id : typing.Optional[str]
            The ID of the processor to filter evaluation sets by.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_by : typing.Optional[SortByEnum]
            Sorts the evaluation sets by the given field.

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the evaluation sets in ascending or descending order. Ascending order means the earliest evaluation set is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetListResponse
            Successfully retrieved evaluation sets

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.evaluation_set.list(processor_id='processor_id_here', next_page_token='xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=', )
        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            processor_id=processor_id,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self, *, name: str, description: str, processor_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> EvaluationSetCreateResponse:
        """
        Evaluation sets are collections of files and expected outputs that are used to evaluate the performance of a given processor in Extend. This endpoint will create a new evaluation set in Extend, which items can be added to using the [Create Evaluation Set Item](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/create-evaluation-set-item) endpoint.

        Note: it is not necessary to create an evaluation set via API. You can also create an evaluation set via the Extend dashboard and take the ID from there.

        Parameters
        ----------
        name : str
            The name of the evaluation set.

            Example: `"Invoice Processing Test Set"`

        description : str
            A description of what this evaluation set is used for.

            Example: `"Q4 2023 vendor invoices"`

        processor_id : str
            The ID of the processor to create an evaluation set for. Evaluation sets can in theory be run against any processor, but it is required to associate the evaluation set with a primary processor.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetCreateResponse
            Successfully created evaluation set

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.evaluation_set.create(name='My Evaluation Set', description='My Evaluation Set Description', processor_id='processor_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name, description=description, processor_id=processor_id, request_options=request_options
        )
        return _response.data

    async def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EvaluationSetGetResponse:
        """
        Retrieve a specific evaluation set by ID. This returns an evaluation set object, but does not include the items in the evaluation set. You can use the [List Evaluation Set Items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/list-evaluation-set-items) endpoint to get the items in an evaluation set.

        Parameters
        ----------
        id : str
            The ID of the evaluation set to retrieve.

            Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetGetResponse
            Successfully retrieved evaluation set

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.evaluation_set.get(id='evaluation_set_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from .base_metrics import BaseMetrics
from .extract_metrics_field_metrics import ExtractMetricsFieldMetrics


class ExtractMetrics(BaseMetrics):
    """
    Metrics specific to extraction processors
    """

    type: typing.Optional[typing.Literal["EXTRACT"]] = pydantic.Field(default=None)
    """
    The type of metrics. Will always be `"EXTRACT"` for extraction processors.
    """

    field_metrics: typing_extensions.Annotated[
        typing.Optional[ExtractMetricsFieldMetrics], FieldMetadata(alias="fieldMetrics")
    ] = pydantic.Field(default=None)
    """
    Record mapping field names to their respective metrics.
    """

    array_cardinality_metrics: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="arrayCardinalityMetrics")
    ] = pydantic.Field(default=None)
    """
    Maps the root array field name to a number indicating how many times the array field has the correct number of rows extracted.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.processor_type import ProcessorType
from .raw_client import AsyncRawProcessorClient, RawProcessorClient
from .types.processor_create_request_config import ProcessorCreateRequestConfig
from .types.processor_create_response import ProcessorCreateResponse
from .types.processor_update_request_config import ProcessorUpdateRequestConfig
from .types.processor_update_response import ProcessorUpdateResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProcessorClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawProcessorClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawProcessorClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawProcessorClient
        """
        return self._raw_client

    def create(
        self,
        *,
        name: str,
        type: ProcessorType,
        clone_processor_id: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorCreateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorCreateResponse:
        """
        Create a new processor in Extend, optionally cloning from an existing processor

        Parameters
        ----------
        name : str
            The name of the new processor

        type : ProcessorType

        clone_processor_id : typing.Optional[str]
            The ID of an existing processor to clone. One of `cloneProcessorId` or `config` must be provided.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        config : typing.Optional[ProcessorCreateRequestConfig]
            The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorCreateResponse
            Successfully created processor

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.processor.create(name='My Processor Name', type="EXTRACT", )
        """
        _response = self._raw_client.create(
            name=name, type=type, clone_processor_id=clone_processor_id, config=config, request_options=request_options
        )
        return _response.data

    def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorUpdateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorUpdateResponse:
        """
        Update an existing processor in Extend

        Parameters
        ----------
        id : str
            The ID of the processor to update.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name for the processor

        config : typing.Optional[ProcessorUpdateRequestConfig]
            The new configuration for the processor. The type of configuration must match the processor type:
            * For classification processors, use `ClassificationConfig`
            * For extraction processors, use `ExtractionConfig`
            * For splitter processors, use `SplitterConfig`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorUpdateResponse
            Successfully updated processor

        Examples
        --------
        from extend_ai import Extend
        client = Extend(token="YOUR_TOKEN", )
        client.processor.update(id='processor_id_here', )
        """
        _response = self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data


class AsyncProcessorClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawProcessorClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawProcessorClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawProcessorClient
        """
        return self._raw_client

    async def create(
        self,
        *,
        name: str,
        type: ProcessorType,
        clone_processor_id: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorCreateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorCreateResponse:
        """
        Create a new processor in Extend, optionally cloning from an existing processor

        Parameters
        ----------
        name : str
            The name of the new processor

        type : ProcessorType

        clone_processor_id : typing.Optional[str]
            The ID of an existing processor to clone. One of `cloneProcessorId` or `config` must be provided.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        config : typing.Optional[ProcessorCreateRequestConfig]
            The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorCreateResponse
            Successfully created processor

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.processor.create(name='My Processor Name', type="EXTRACT", )
        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name, type=type, clone_processor_id=clone_processor_id, config=config, request_options=request_options
        )
        return _response.data

    async def update(
        self,
        id: str,
        *,
        name: typing.Optional[str] = OMIT,
        config: typing.Optional[ProcessorUpdateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProcessorUpdateResponse:
        """
        Update an existing processor in Extend

        Parameters
        ----------
        id : str
            The ID of the processor to update.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        name : typing.Optional[str]
            The new name for the processor

        config : typing.Optional[ProcessorUpdateRequestConfig]
            The new configuration for the processor. The type of configuration must match the processor type:
            * For classification processors, use `ClassificationConfig`
            * For extraction processors, use `ExtractionConfig`
            * For splitter processors, use `SplitterConfig`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProcessorUpdateResponse
            Successfully updated processor

        Examples
        --------
        from extend_ai import AsyncExtend
        import asyncio
        client = AsyncExtend(token="YOUR_TOKEN", )
        async def main() -> None:
            await client.processor.update(id='processor_id_here', )
        asyncio.run(main())
        """
        _response = await self._raw_client.update(id, name=name, config=config, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .page_ranges import PageRanges


class ParseConfigAdvancedOptions(UncheckedBaseModel):
    page_rotation_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="pageRotationEnabled")
    ] = pydantic.Field(default=None)
    """
    Whether to automatically detect and correct page rotation.
    """

    agentic_ocr_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="agenticOcrEnabled")
    ] = pydantic.Field(default=None)
    """
    Whether to enable agentic OCR corrections using VLM-based review and correction of OCR errors for messy handwriting and poorly scanned text.
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .provided_extraction_field_result_type import ProvidedExtractionFieldResultType


class ProvidedExtractionFieldResult(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    The unique identifier for this field
    """

    value: typing.Optional[typing.Any] = None
    type: typing.Optional[ProvidedExtractionFieldResultType] = pydantic.Field(default=None)
    """
    The type of the extraction field result
    """

    confidence: typing.Optional[float] = pydantic.Field(default=None)
    """
    A value between 0 and 1 indicating confidence in the extraction. Will be set to 1 if not provided.
    """

    page: typing.Optional[float] = pydantic.Field(default=None)
    """
    The page number where this field was extracted from
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .processor_version_create_request_config import (
    ProcessorVersionCreateRequestConfig,
    ProcessorVersionCreateRequestConfig_Classify,
    ProcessorVersionCreateRequestConfig_Extract,
    ProcessorVersionCreateRequestConfig_Splitter,
)
from .processor_version_create_request_release_type import ProcessorVersionCreateRequestReleaseType
from .processor_version_create_response import ProcessorVersionCreateResponse
from .processor_version_get_response import ProcessorVersionGetResponse
from .processor_version_list_response import ProcessorVersionListResponse

__all__ = [
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .file import File
from .json_object import JsonObject
from .processor_run import ProcessorRun
from .step_run import StepRun
from .workflow import Workflow
from .workflow_status import WorkflowStatus


class WorkflowRun(UncheckedBaseModel):
    object: str = pydantic.Field()
    """
    The type of response. In this case, it will always be `"workflow_run"`.
    """

    id: str = pydantic.Field()
    """
    The ID of the workflow run.
    
    Example: `"workflow_run_xKm9pNv3qWsY_jL2tR5Dh"`
    """

    name: str = pydantic.Field()
    """
    The name of the workflow run.
    
    Example: `"myFirstFile.pdf"`
    """

    url: str = pydantic.Field()
    """
    A URL to view this workflow run in the Extend UI.
    
    Example: `"https://dashboard.extend.ai/workflows/workflow_Bk9mNp2qWs5_xL8vR4tYh?workflowRunId=workflow_run_Zj3nMx7ZPd9f4c2WQ_kAg"`
    """

    status: WorkflowStatus
    metadata: JsonObject = pydantic.Field()
    """
    The metadata that was passed in when running the Workflow.
    """

    batch_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="batchId")] = pydantic.Field(
        default=None
    )
    """
    The batch ID of the WorkflowRun. If this WorkflowRun was created as part of a batch of files, all runs in that batch will have the same batch ID.
    
    Example: `"batch_7Ws31-F5"`
    """

    files: typing.List[File]
    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(default=None)
    )
    """
    The reason why the workflow run failed. Will only be included if the workflow run status is "FAILED".
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(default=None)
    )
    """
    A more detailed message about the failure. Will only be included if the workflow run status is "FAILED".
    """

    initial_run_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="initialRunAt")] = pydantic.Field()
    """
    The time (in UTC) at which the workflow run was created. Will follow the RFC 3339 format.
    
    Example: `"2025-04-28T17:01:39.285Z"`
    """

    reviewed_by: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="reviewedBy")] = pydantic.Field(
        default=None
    )
    """
    The email address of the person who reviewed the workflow run. Will not be included if the workflow run has not been reviewed.
    
    Example: `"jane.doe@example.com"`
    """

    reviewed: bool = pydantic.Field()
    """
    Whether the workflow run has been reviewed.
    """

    rejection_note: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rejectionNote")] = (
        pydantic.Field(default=None)
    )
    """
    A note that is added if a workflow run is rejected.
    
    Example: `"Invalid invoice format"`
    """

    reviewed_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="reviewedAt")] = (
        pydantic.Field(default=None)
    )
    """
    The time (in UTC) at which the workflow run was reviewed. Will follow the RFC 3339 format. Will not be included if the workflow run has not been reviewed.
    
    Example: `"2024-03-21T16:45:00Z"`
    """

    start_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="startTime")] = (
        pydantic.Field(default=None)
    )
    """
    The time (in UTC) at which the workflow run started executing. This will always be after the `initialRunAt` time. Will follow the RFC 3339 format. Will not be included if the workflow run has not started executing.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    end_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="endTime")] = (
        pydantic.Field(default=None)
    )
    """
    The time (in UTC) that the workflow finished executing. Will follow the RFC 3339 format. Will not be included if the workflow run has not finished executing.
    
    Example: `"2024-03-21T15:35:00Z"`
    """

    outputs: typing.List[ProcessorRun]
    step_runs: typing_extensions.Annotated[typing.List[StepRun], FieldMetadata(alias="stepRuns")] = pydantic.Field()
    """
    An array of WorkflowStepRun objects. Each WorkflowStepRun represents a single run of a WorkflowStep and contains details about the step and the run's output.
    
    Note: This field currently supports External Data Validation and Rule Validation step types. Document processor run outputs are included in the outputs field.
    """

    workflow: Workflow

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .extraction_field import ExtractionField  # noqa: E402, F401, I001

update_forward_refs(WorkflowRun)



# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_extraction_field_result import ProvidedExtractionFieldResult

ProvidedFieldsArrayOutput = typing.Dict[str, ProvidedExtractionFieldResult]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import BatchWorkflowRunCreateRequestInputsItem, BatchWorkflowRunCreateResponse

__all__ = ["BatchWorkflowRunCreateRequestInputsItem", "BatchWorkflowRunCreateResponse"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .parser_run_delete_response import ParserRunDeleteResponse
from .parser_run_get_request_response_type import ParserRunGetRequestResponseType
from .parser_run_get_response import ParserRunGetResponse
from .parser_run_get_response_parser_run import (
    ParserRunGetResponseParserRun,
    ParserRunGetResponseParserRun_ParserRun,
    ParserRunGetResponseParserRun_ParserRunStatus,
)

__all__ = [
    "ParserRunDeleteResponse",
    "ParserRunGetRequestResponseType",
    "ParserRunGetResponse",
    "ParserRunGetResponseParserRun",
    "ParserRunGetResponseParserRun_ParserRun",
    "ParserRunGetResponseParserRun_ParserRunStatus",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import EvaluationSetCreateResponse, EvaluationSetGetResponse, EvaluationSetListResponse

__all__ = ["EvaluationSetCreateResponse", "EvaluationSetGetResponse", "EvaluationSetListResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

ApiVersionEnum = typing.Union[
    typing.Literal["2025-04-21", "2024-12-23", "2024-11-14", "2024-07-30", "2024-02-01"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventProcessorRunEventType = typing.Union[
    typing.Literal["processor_run.processed", "processor_run.failed"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from ...types.classification import Classification
from ...types.classification_advanced_options import ClassificationAdvancedOptions
from ...types.classification_config_base_processor import ClassificationConfigBaseProcessor
from ...types.extraction_advanced_options import ExtractionAdvancedOptions
from ...types.extraction_config_base_processor import ExtractionConfigBaseProcessor
from ...types.json_object import JsonObject
from ...types.parse_config import ParseConfig
from ...types.splitter_advanced_options import SplitterAdvancedOptions
from ...types.splitter_config_base_processor import SplitterConfigBaseProcessor


class ProcessorCreateRequestConfig_Classify(UncheckedBaseModel):
    """
    The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.
    """

    type: typing.Literal["CLASSIFY"] = "CLASSIFY"
    base_processor: typing_extensions.Annotated[
        typing.Optional[ClassificationConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    classifications: typing.List[Classification]
    classification_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="classificationRules")
    ] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[ClassificationAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorCreateRequestConfig_Extract(UncheckedBaseModel):
    """
    The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.
    """

    type: typing.Literal["EXTRACT"] = "EXTRACT"
    base_processor: typing_extensions.Annotated[
        typing.Optional[ExtractionConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    extraction_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="extractionRules")] = None
    schema_: typing_extensions.Annotated[typing.Optional[JsonObject], FieldMetadata(alias="schema")] = None
    fields: typing.Optional[typing.List["ExtractionField"]] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[ExtractionAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from ...types.extraction_field import ExtractionField  # noqa: E402, F401, I001


class ProcessorCreateRequestConfig_Splitter(UncheckedBaseModel):
    """
    The configuration for the processor. The type of configuration must match the processor type. One of `cloneProcessorId` or `config` must be provided.
    """

    type: typing.Literal["SPLITTER"] = "SPLITTER"
    base_processor: typing_extensions.Annotated[
        typing.Optional[SplitterConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = None
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = None
    split_classifications: typing_extensions.Annotated[
        typing.List[Classification], FieldMetadata(alias="splitClassifications")
    ]
    split_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="splitRules")] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[SplitterAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = None
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ProcessorCreateRequestConfig = typing_extensions.Annotated[
    typing.Union[
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
    ],
    UnionMetadata(discriminant="type"),
]
update_forward_refs(ProcessorCreateRequestConfig_Extract)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.batch_workflow_run_file_input import BatchWorkflowRunFileInput
from ...types.json_object import JsonObject


class BatchWorkflowRunCreateRequestInputsItem(UncheckedBaseModel):
    file: typing.Optional[BatchWorkflowRunFileInput] = pydantic.Field(default=None)
    """
    The file to be processed. Either `file` or `rawText` must be provided for each input.
    """

    raw_text: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rawText")] = pydantic.Field(
        default=None
    )
    """
    A string containing raw text data to be processed. This will be treated as a `.txt` file by the workflow. Use the `file` parameter for structured data or specific file types. Either `file` or `rawText` must be provided for each input.
    """

    metadata: typing.Optional[JsonObject] = pydantic.Field(default=None)
    """
    An optional object containing arbitrary key-value pairs to associate with this specific workflow run. This metadata will be included in webhook payloads and responses when fetching the workflow run details.
    """

    secrets: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    An optional object containing secrets to be used by processors within the workflow for this specific run. Secrets provided here override any globally configured secrets for the workflow.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .step_run_output_rules_item import StepRunOutputRulesItem


class StepRunOutput(UncheckedBaseModel):
    """
    The output of the WorkflowStepRun. The shape of the output depends on the type of the WorkflowStep in the `step` field:
    * For `"EXTERNAL_DATA_VALIDATION"` steps - The output will be the same object that was returned by the external endpoint configured for this step
    * For `"RULE_VALIDATION"` steps - See the below shape:
    """

    rules: typing.Optional[typing.List[StepRunOutputRulesItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ExtractMetricsFieldMetrics(UncheckedBaseModel):
    """
    Record mapping field names to their respective metrics.
    """

    mean_confidence: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="meanConfidence")] = (
        pydantic.Field(default=None)
    )
    """
    The mean confidence score for this field across all documents.
    """

    recall_perc: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="recallPerc")] = (
        pydantic.Field(default=None)
    )
    """
    The recall percentage for this field, representing how many of the expected values were correctly extracted.
    """

    precision_perc: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="precisionPerc")] = (
        pydantic.Field(default=None)
    )
    """
    The precision percentage for this field, representing how many of the extracted values were correct.
    """

    field_metrics: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="fieldMetrics")
    ] = pydantic.Field(default=None)
    """
    For nested object fields, this contains metrics for the child fields. Has the same structure as the parent fieldMetrics.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .block_bounding_box import BlockBoundingBox
from .block_details import BlockDetails
from .block_metadata import BlockMetadata
from .block_polygon_item import BlockPolygonItem
from .block_type import BlockType


class Block(UncheckedBaseModel):
    object: str = pydantic.Field()
    """
    The type of object. In this case, it will always be `"block"`.
    """

    id: str = pydantic.Field()
    """
    A unique identifier for the block, deterministically generated as a hash of the block content.
    """

    type: BlockType = pydantic.Field()
    """
    The type of block:
    * `"text"` - Regular text content
    * `"heading"` - Section or document headings 
    * `"section_heading"` - Subsection headings
    * `"table"` - Tabular data with rows and columns
    * `"table_head"` - Table header cells
    * `"table_cell"` - Table body cells
    * `"figure"` - Images, charts, diagrams, or logos
    """

    content: str = pydantic.Field()
    """
    The textual content of the block formatted based on the target format.
    """

    details: BlockDetails = pydantic.Field()
    """
    Additional details specific to the block type. The schema depends on the block type.
    """

    metadata: BlockMetadata = pydantic.Field()
    """
    Metadata about the block.
    """

    polygon: typing.List[BlockPolygonItem] = pydantic.Field()
    """
    An array of points defining the polygon that bounds the block.
    """

    bounding_box: typing_extensions.Annotated[BlockBoundingBox, FieldMetadata(alias="boundingBox")] = pydantic.Field()
    """
    A simplified bounding box for the block.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ParseErrorCode = typing.Union[
    typing.Literal[
        "INVALID_CONFIG_OPTIONS",
        "UNABLE_TO_DOWNLOAD_FILE",
        "FILE_TYPE_NOT_SUPPORTED",
        "FILE_SIZE_TOO_LARGE",
        "CORRUPT_FILE",
        "OCR_ERROR",
        "PASSWORD_PROTECTED_FILE",
        "FAILED_TO_CONVERT_TO_PDF",
        "FAILED_TO_GENERATE_TARGET_FORMAT",
        "INTERNAL_ERROR",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ParseAsyncRequestFile(UncheckedBaseModel):
    """
    A file object containing either a URL or a fileId.
    """

    file_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fileName")] = pydantic.Field(
        default=None
    )
    """
    The name of the file. If not set, the file name is taken from the url.
    """

    file_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fileUrl")] = pydantic.Field(
        default=None
    )
    """
    A URL to download the file. For production use cases, we recommend using presigned URLs with a 5-15 minute expiration time. One of `fileUrl` or `fileId` must be provided.
    """

    file_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fileId")] = pydantic.Field(
        default=None
    )
    """
    If you already have an Extend file id (for instance from running a workflow or a previous [file upload](https://docs.extend.ai/2025-04-21/developers/api-reference/file-endpoints/upload-file)) then you can use that file id when running the parse endpoint so that it leverage any cached data that might be available. The file id will start with "file_". One of `fileUrl` or `fileId` must be provided.
    
    Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_event_workflow_event_type import WebhookEventWorkflowEventType
from .workflow import Workflow


class WebhookEventWorkflow(UncheckedBaseModel):
    """
    Webhook event for workflow related events
    """

    event_type: typing_extensions.Annotated[
        typing.Optional[WebhookEventWorkflowEventType], FieldMetadata(alias="eventType")
    ] = None
    payload: typing.Optional[Workflow] = None
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field()
    """
    Unique identifier for the event
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    EvaluationSetItemCreateBatchRequestItemsItem,
    EvaluationSetItemCreateBatchResponse,
    EvaluationSetItemCreateResponse,
    EvaluationSetItemListResponse,
    EvaluationSetItemUpdateResponse,
)

__all__ = [
    "EvaluationSetItemCreateBatchRequestItemsItem",
    "EvaluationSetItemCreateBatchResponse",
    "EvaluationSetItemCreateResponse",
    "EvaluationSetItemListResponse",
    "EvaluationSetItemUpdateResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.not_found_error import NotFoundError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.error import Error
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_by_enum import SortByEnum
from ..types.sort_dir_enum import SortDirEnum
from .types.evaluation_set_create_response import EvaluationSetCreateResponse
from .types.evaluation_set_get_response import EvaluationSetGetResponse
from .types.evaluation_set_list_response import EvaluationSetListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawEvaluationSetClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        processor_id: typing.Optional[str] = None,
        sort_by: typing.Optional[SortByEnum] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EvaluationSetListResponse]:
        """
        List evaluation sets in your account. You can use the `processorId` parameter to filter evaluation sets by processor.

        This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        processor_id : typing.Optional[str]
            The ID of the processor to filter evaluation sets by.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_by : typing.Optional[SortByEnum]
            Sorts the evaluation sets by the given field.

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the evaluation sets in ascending or descending order. Ascending order means the earliest evaluation set is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EvaluationSetListResponse]
            Successfully retrieved evaluation sets
        """
        _response = self._client_wrapper.httpx_client.request(
            "evaluation_sets",
            method="GET",
            params={
                "processorId": processor_id,
                "sortBy": sort_by,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetListResponse,
                    construct_type(
                        type_=EvaluationSetListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self, *, name: str, description: str, processor_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EvaluationSetCreateResponse]:
        """
        Evaluation sets are collections of files and expected outputs that are used to evaluate the performance of a given processor in Extend. This endpoint will create a new evaluation set in Extend, which items can be added to using the [Create Evaluation Set Item](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/create-evaluation-set-item) endpoint.

        Note: it is not necessary to create an evaluation set via API. You can also create an evaluation set via the Extend dashboard and take the ID from there.

        Parameters
        ----------
        name : str
            The name of the evaluation set.

            Example: `"Invoice Processing Test Set"`

        description : str
            A description of what this evaluation set is used for.

            Example: `"Q4 2023 vendor invoices"`

        processor_id : str
            The ID of the processor to create an evaluation set for. Evaluation sets can in theory be run against any processor, but it is required to associate the evaluation set with a primary processor.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EvaluationSetCreateResponse]
            Successfully created evaluation set
        """
        _response = self._client_wrapper.httpx_client.request(
            "evaluation_sets",
            method="POST",
            json={
                "name": name,
                "description": description,
                "processorId": processor_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetCreateResponse,
                    construct_type(
                        type_=EvaluationSetCreateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EvaluationSetGetResponse]:
        """
        Retrieve a specific evaluation set by ID. This returns an evaluation set object, but does not include the items in the evaluation set. You can use the [List Evaluation Set Items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/list-evaluation-set-items) endpoint to get the items in an evaluation set.

        Parameters
        ----------
        id : str
            The ID of the evaluation set to retrieve.

            Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EvaluationSetGetResponse]
            Successfully retrieved evaluation set
        """
        _response = self._client_wrapper.httpx_client.request(
            f"evaluation_sets/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetGetResponse,
                    construct_type(
                        type_=EvaluationSetGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawEvaluationSetClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        processor_id: typing.Optional[str] = None,
        sort_by: typing.Optional[SortByEnum] = None,
        sort_dir: typing.Optional[SortDirEnum] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EvaluationSetListResponse]:
        """
        List evaluation sets in your account. You can use the `processorId` parameter to filter evaluation sets by processor.

        This endpoint returns a paginated response. You can use the `nextPageToken` to fetch subsequent results.

        Parameters
        ----------
        processor_id : typing.Optional[str]
            The ID of the processor to filter evaluation sets by.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_by : typing.Optional[SortByEnum]
            Sorts the evaluation sets by the given field.

        sort_dir : typing.Optional[SortDirEnum]
            Sorts the evaluation sets in ascending or descending order. Ascending order means the earliest evaluation set is returned first.

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EvaluationSetListResponse]
            Successfully retrieved evaluation sets
        """
        _response = await self._client_wrapper.httpx_client.request(
            "evaluation_sets",
            method="GET",
            params={
                "processorId": processor_id,
                "sortBy": sort_by,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetListResponse,
                    construct_type(
                        type_=EvaluationSetListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self, *, name: str, description: str, processor_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EvaluationSetCreateResponse]:
        """
        Evaluation sets are collections of files and expected outputs that are used to evaluate the performance of a given processor in Extend. This endpoint will create a new evaluation set in Extend, which items can be added to using the [Create Evaluation Set Item](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/create-evaluation-set-item) endpoint.

        Note: it is not necessary to create an evaluation set via API. You can also create an evaluation set via the Extend dashboard and take the ID from there.

        Parameters
        ----------
        name : str
            The name of the evaluation set.

            Example: `"Invoice Processing Test Set"`

        description : str
            A description of what this evaluation set is used for.

            Example: `"Q4 2023 vendor invoices"`

        processor_id : str
            The ID of the processor to create an evaluation set for. Evaluation sets can in theory be run against any processor, but it is required to associate the evaluation set with a primary processor.

            Example: `"dp_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EvaluationSetCreateResponse]
            Successfully created evaluation set
        """
        _response = await self._client_wrapper.httpx_client.request(
            "evaluation_sets",
            method="POST",
            json={
                "name": name,
                "description": description,
                "processorId": processor_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetCreateResponse,
                    construct_type(
                        type_=EvaluationSetCreateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EvaluationSetGetResponse]:
        """
        Retrieve a specific evaluation set by ID. This returns an evaluation set object, but does not include the items in the evaluation set. You can use the [List Evaluation Set Items](https://docs.extend.ai/2025-04-21/developers/api-reference/evaluation-set-endpoints/list-evaluation-set-items) endpoint to get the items in an evaluation set.

        Parameters
        ----------
        id : str
            The ID of the evaluation set to retrieve.

            Example: `"ev_2LcgeY_mp2T5yPaEuq5Lw"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EvaluationSetGetResponse]
            Successfully retrieved evaluation set
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"evaluation_sets/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EvaluationSetGetResponse,
                    construct_type(
                        type_=EvaluationSetGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        construct_type(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
